@@ -7,14 +7,15 @@ use Exporter   ();
 use File::Spec ();
 use Test::More ();
 
-use vars qw{$VERSION @ISA @EXPORT @CALL_FUNCS};
+our $VERSION = '1.42';
+our @ISA     = 'Exporter';
+our @EXPORT  = qw/connect_ok dies dbfile @CALL_FUNCS/;
+our @CALL_FUNCS;
+
 my $parent;
 my %dbfiles;
-BEGIN {
-	$VERSION = '1.37';
-	@ISA     = 'Exporter';
-	@EXPORT  = qw/connect_ok dies dbfile @CALL_FUNCS/;
 
+BEGIN {
 	# Allow tests to load modules bundled in /inc
 	unshift @INC, 'inc';
 
@@ -24,7 +25,7 @@ BEGIN {
 # Always load the DBI module
 use DBI ();
 
-sub dbfile { $dbfiles{$_[0]} }
+sub dbfile { $dbfiles{$_[0]} ||= (defined $_[0] && length $_[0] && $_[0] ne ':memory:') ? $_[0] . $$ : $_[0] }
 
 # Delete temporary files
 sub clean {
@@ -46,9 +47,8 @@ END   { clean() }
 # A simplified connect function for the most common case
 sub connect_ok {
 	my $attr = { @_ };
-	my $dbfile = delete $attr->{dbfile} || ':memory:';
-	$dbfiles{$dbfile} = ($dbfile ne ':memory:') ? $dbfile . $$ : $dbfile;
-	my @params = ( "dbi:SQLite:dbname=$dbfiles{$dbfile}", '', '' );
+	my $dbfile = dbfile(defined $attr->{dbfile} ? delete $attr->{dbfile} : ':memory:');
+	my @params = ( "dbi:SQLite:dbname=$dbfile", '', '' );
 	if ( %$attr ) {
 		push @params, $attr;
 	}
